@@ -7,7 +7,12 @@ import json
 import os
 import re
 import time
-import urlparse
+
+try:
+    from urlparse import urlparse
+except ImportError:
+    # Python 3.3?
+    from urllib.parse import urlparse
 
 from kazoo.client import KazooClient
 
@@ -128,7 +133,7 @@ class Proxy(ProxyType("ProxyBase", (object,), {})):
         if not re.match("^\w+://", url_string):
             url_string = "file://%s" % (url_string)
 
-        return urlparse.urlparse(url_string)
+        return urlparse(url_string)
 
     def __enter__(self):
         pass
@@ -137,16 +142,16 @@ class Proxy(ProxyType("ProxyBase", (object,), {})):
         pass
 
     def check_path(self):
-        raise NotImplementedError, "check_path must be implemented"
+        raise NotImplementedError("check_path must be implemented")
 
     def read_path(self):
-        raise NotImplementedError, "read_path must be implemented"
+        raise NotImplementedError("read_path must be implemented")
 
     def write_path(self, path_value):
-        raise NotImplementedError, "write_path must be implemented"
+        raise NotImplementedError("write_path must be implemented")
 
     def children_of(self, async):
-        raise NotImplementedError, "children_of must be implemented"
+        raise NotImplementedError("children_of must be implemented")
 
 
 class ZKProxy(Proxy):
@@ -337,9 +342,9 @@ class JSONProxy(Proxy):
 
     def children_of(self, async):
         offs = 1 if self.path == "/" else len(self.path) + 1
-        return map(lambda c: c[offs:],
-                   filter(lambda k: k != self.path and k.startswith(self.path),
-                          self._tree.keys()))
+        def good(k):
+            return k != self.path and k.startswith(self.path)
+        return list(map(lambda c: c[offs:], list(filter(good, self._tree.keys()))))
 
 
 def do_copy(src, dst, async=False, verbose=False):
