@@ -139,7 +139,7 @@ class Shell(AugumentedCmd):
         get_acls /zookeeper
         [ACL(perms=31, acl_list=['ALL'], id=Id(scheme=u'world', id=u'anyone'))]
         """
-        print(self._zk.get_acls(params.path)[0])
+        print(self._zk.get_acls(params.path)[0], file=self._output)
 
     def complete_get_acls(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -229,10 +229,10 @@ class Shell(AugumentedCmd):
         ├── foo
         ├── bar
         """
-        print(".")
-        self._zk.tree(params.path,
-                      params.max_depth,
-                      lambda c,l: print(u"%s├── %s" % (u"│   " * l, c)))
+        print(".", file=self._output)
+        def print_node(c, l):
+            print(u"%s├── %s" % (u"│   " * l, c), file=self._output)
+        self._zk.tree(params.path, params.max_depth, print_node)
 
     def complete_tree(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -241,7 +241,7 @@ class Shell(AugumentedCmd):
     @ensure_params(Optional("path"))
     @check_path_exists
     def do_du(self, params):
-        print(pretty_bytes(self._zk.du(params.path)))
+        print(pretty_bytes(self._zk.du(params.path)), file=self._output)
 
     @connected
     @ensure_params(Optional("path"), Required("match"))
@@ -260,7 +260,7 @@ class Shell(AugumentedCmd):
                       params.match,
                       True,
                       0,
-                      lambda p: print(p))
+                      lambda p: print(p, file=self._output))
 
     def complete_find(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -282,7 +282,7 @@ class Shell(AugumentedCmd):
                       params.match,
                       True,
                       re.IGNORECASE,
-                      lambda p: print(p))
+                      lambda p: print(p, file=self._output))
 
     def complete_ifind(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -298,11 +298,11 @@ class Shell(AugumentedCmd):
         /passwd: unbound:x:992:991:Unbound DNS resolver:/etc/unbound:/sbin/nologin
         /copy/passwd: unbound:x:992:991:Unbound DNS resolver:/etc/unbound:/sbin/nologin
         """
-        self._.zk.grep(params.path,
-                       params.content,
-                       params.show_matches,
-                       flags=0,
-                       callback=lambda p: print(p))
+        self._zk.grep(params.path,
+                      params.content,
+                      params.show_matches,
+                      flags=0,
+                      callback=lambda p: print(p, file=self._output))
 
     def complete_grep(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -322,7 +322,7 @@ class Shell(AugumentedCmd):
                       params.content,
                       params.show_matches,
                       flags=re.IGNORECASE,
-                      callback=lambda p: print(p))
+                      callback=lambda p: print(p, file=self._output))
 
     def complete_igrep(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -488,7 +488,7 @@ server=%s""" % (self._zk.state,
     def do_mntr(self, params):
         host = params.host if params.host != "" else None
         try:
-            print(self._zk.mntr(host))
+            print(self._zk.mntr(host), file=self._output)
         except AugumentedClient.CmdFailed as ex:
             print(ex)
 
@@ -496,7 +496,7 @@ server=%s""" % (self._zk.state,
     def do_cons(self, params):
         host = params.host if params.host != "" else None
         try:
-            print(self._zk.cons(host))
+            print(self._zk.cons(host), file=self._output)
         except AugumentedClient.CmdFailed as ex:
             print(ex)
 
@@ -504,7 +504,7 @@ server=%s""" % (self._zk.state,
     def do_dump(self, params):
         host = params.host if params.host != "" else None
         try:
-            print(self._zk.dump(host))
+            print(self._zk.dump(host), file=self._output)
         except AugumentedClient.CmdFailed as ex:
             print(ex)
 
